@@ -3,4 +3,8 @@ from easyconfig.__version__ import __version__
 
 # isort: split
 
-from easyconfig.models import AppConfigModel, ConfigModel, PathModel
+from easyconfig.models import AppConfigMixin, ConfigMixin
+
+# isort: split
+
+from easyconfig.config_objs import create_app_config
