@@ -1,4 +1,4 @@
-import io
+from io import BytesIO
 from typing import Union
 
 from easyconfig.yaml import yaml_rt
@@ -37,13 +37,15 @@ def remove_none(obj: Union[dict]):
         obj.pop(k)
 
 
-def write_aligned_yaml(obj, file_obj):
-    buffer = io.BytesIO()
+def write_aligned_yaml(obj, file_obj, extra_indent: int = 0):
+    assert extra_indent >= 0, extra_indent
+
+    buffer = BytesIO()
     yaml_rt.dump(obj, buffer)
 
     loaded_obj = yaml_rt.load(buffer.getvalue())
     remove_none(loaded_obj)
-    align_comments(loaded_obj, 1)
+    align_comments(loaded_obj, extra_indent)
 
     yaml_rt.dump(loaded_obj, file_obj)
     return None
